searchData={"items":[{"type":"module","title":"EIP712","doc":"Documentation for `EIP712`.","ref":"EIP712.html"},{"type":"function","title":"EIP712.sign/3","doc":"","ref":"EIP712.html#sign/3"},{"type":"function","title":"EIP712.sign!/3","doc":"Sign a message.\n\n    iex> %EIP712.Typed{\n    ...>   domain: %EIP712.Typed.Domain{\n    ...>     chain_id: 1,\n    ...>     name: \"Test\",\n    ...>     verifying_contract: EIP712.Util.decode_hex!(\"0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC\"),\n    ...>     version: \"1\"\n    ...>   },\n    ...>   types: %{\n    ...>     \"Test\" => %EIP712.Typed.Type{fields: [{\"items\", {:array, :string}}]}\n    ...>   },\n    ...>   value: %{\n    ...>     \"items\" => [\"item1\", \"item2\"]\n    ...>   }\n    ...> }\n    ...> |> EIP712.sign!(\n    ...>   EIP712.Util.decode_hex!(\"0xac0974bec39a17e36ba4a6b4d238ff944bacb478cbed5efcae784d7bf4f2ff80\"),\n    ...>   hex?: true\n    ...> )\n    \"0x97ce47cfb1497f72019606ba462c3ab4e3552c4225f3b7b75ca42c5787a19b7c29d53b9fe402102a82ea782e806224f819b326b74f98049fe59486640d6fa2911c\"","ref":"EIP712.html#sign!/3"},{"type":"module","title":"EIP712.Hash","doc":"","ref":"EIP712.Hash.html"},{"type":"function","title":"EIP712.Hash.keccak/1","doc":"Returns the keccak of the given binary message.","ref":"EIP712.Hash.html#keccak/1"},{"type":"function","title":"Examples - EIP712.Hash.keccak/1","doc":"iex> EIP712.Hash.keccak(\"test\")\n   >","ref":"EIP712.Hash.html#keccak/1-examples"},{"type":"function","title":"EIP712.Hash.keccak_unsigned/1","doc":"Returns the keccak of the given binary message, as an unsigned.","ref":"EIP712.Hash.html#keccak_unsigned/1"},{"type":"function","title":"Examples - EIP712.Hash.keccak_unsigned/1","doc":"iex> EIP712.Hash.keccak_unsigned(\"test\")\n  70622639689279718371527342103894932928233838121221666359043189029713682937432","ref":"EIP712.Hash.html#keccak_unsigned/1-examples"},{"type":"module","title":"EIP712.Typed","doc":"Module to build EIP-712 typed data, which can then be signed or recovered from.","ref":"EIP712.Typed.html"},{"type":"function","title":"EIP712.Typed.deserialize/1","doc":"Deserializes a Typed value from JSON or a map into a struct.","ref":"EIP712.Typed.html#deserialize/1"},{"type":"function","title":"Examples - EIP712.Typed.deserialize/1","doc":"iex> %{\n    ...>   \"domain\" => %{\n    ...>     \"name\" => \"Ether Mail\",\n    ...>     \"version\" => \"1\",\n    ...>     \"chainId\" => 1,\n    ...>     \"verifyingContract\" => \"0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC\"\n    ...>   },\n    ...>   \"types\" => %{\n    ...>     \"Person\" => [\n    ...>       %{\n    ...>         \"name\" => \"name\",\n    ...>         \"type\" => \"string\"\n    ...>       },\n    ...>       %{\n    ...>         \"name\" => \"wallet\",\n    ...>         \"type\" => \"address\"\n    ...>       },\n    ...>     ],\n    ...>     \"Mail\" => [\n    ...>       %{\n    ...>         \"name\" => \"from\",\n    ...>         \"type\" => \"Person\"\n    ...>       },\n    ...>       %{\n    ...>         \"name\" => \"to\",\n    ...>         \"type\" => \"Person\"\n    ...>       },\n    ...>       %{\n    ...>         \"name\" => \"contents\",\n    ...>         \"type\" => \"string\"\n    ...>       },\n    ...>     ]\n    ...>   },\n    ...>   \"value\" => %{\n    ...>     \"from\" => %{ \"name\" => \"Cow\", \"wallet\" => \"0xCD2a3d9F938E13CD947Ec05AbC7FE734Df8DD826\" },\n    ...>     \"to\" => %{ \"name\" => \"Bob\", \"wallet\" => \"0xbBbBBBBbbBBBbbbBbbBbbbbBBbBbbbbBbBbbBBbB\" },\n    ...>     \"contents\" => \"Hello, Bob!\"\n    ...>   }\n    ...> }\n    ...> |> EIP712.Typed.deserialize()\n    %EIP712.Typed{\n      domain: %EIP712.Typed.Domain{\n        chain_id: 1,\n        name: \"Ether Mail\",\n        verifying_contract: \"\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\",\n        version: \"1\"\n      },\n      types: %{\n        \"Mail\" => %EIP712.Typed.Type{fields: [{\"from\", \"Person\"}, {\"to\", \"Person\"}, {\"contents\", :string}]},\n        \"Person\" => %EIP712.Typed.Type{fields: [{\"name\", :string}, {\"wallet\", :address}]}\n      },\n      value: %{\n        \"contents\" => \"Hello, Bob!\",\n        \"from\" => %{\n          \"name\" => \"Cow\",\n          \"wallet\" =>  >\n        },\n        \"to\" => %{\n          \"name\" => \"Bob\",\n          \"wallet\" =>\n             >\n        }\n      }\n    }","ref":"EIP712.Typed.html#deserialize/1-examples"},{"type":"function","title":"EIP712.Typed.domain_seperator/1","doc":"Builds a domain struct for a given type, per the EIP-712 spec.","ref":"EIP712.Typed.html#domain_seperator/1"},{"type":"function","title":"Examples - EIP712.Typed.domain_seperator/1","doc":"iex> %EIP712.Typed{\n    ...>   domain: %EIP712.Typed.Domain{\n    ...>     chain_id: 1,\n    ...>     name: \"Ether Mail\",\n    ...>     verifying_contract: EIP712.Util.decode_hex!(\"0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC\"),\n    ...>     version: \"1\"\n    ...>   },\n    ...>   types: %{\n    ...>     \"Mail\" => %EIP712.Typed.Type{fields: [{\"from\", \"Person\"}, {\"to\", \"Person\"}, {\"contents\", :string}]},\n    ...>     \"Person\" => %EIP712.Typed.Type{fields: [{\"name\", :string}, {\"wallet\", :address}]}\n    ...>   },\n    ...>   value: %{\n    ...>     \"contents\" => \"Hello, Bob!\",\n    ...>     \"from\" => %{\n    ...>       \"name\" => \"Cow\",\n    ...>       \"wallet\" => EIP712.Util.decode_hex!(\"0xCD2a3d9F938E13CD947Ec05AbC7FE734Df8DD826\")\n    ...>     },\n    ...>     \"to\" => %{\n    ...>       \"name\" => \"Bob\",\n    ...>       \"wallet\" => EIP712.Util.decode_hex!(\"0xbBbBBBBbbBBBbbbBbbBbbbbBBbBbbbbBbBbbBBbB\")\n    ...>     }\n    ...>   }\n    ...> }\n    ...> |> EIP712.Typed.domain_seperator()\n    ...> |> EIP712.Util.encode_hex()\n    \"0xf2cee375fa42b42143804025fc449deafd50cc031ca257e0b194a650a912090f\"","ref":"EIP712.Typed.html#domain_seperator/1-examples"},{"type":"function","title":"EIP712.Typed.encode/1","doc":"Encodes a given typed value such that it can be signed or recovered.","ref":"EIP712.Typed.html#encode/1"},{"type":"function","title":"Examples - EIP712.Typed.encode/1","doc":"iex> %EIP712.Typed{\n    ...>   domain: %EIP712.Typed.Domain{\n    ...>     chain_id: 1,\n    ...>     name: \"Ether Mail\",\n    ...>     verifying_contract: EIP712.Util.decode_hex!(\"0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC\"),\n    ...>     version: \"1\"\n    ...>   },\n    ...>   types: %{\n    ...>     \"Mail\" => %EIP712.Typed.Type{fields: [{\"from\", \"Person\"}, {\"to\", \"Person\"}, {\"contents\", :string}]},\n    ...>     \"Person\" => %EIP712.Typed.Type{fields: [{\"name\", :string}, {\"wallet\", :address}]}\n    ...>   },\n    ...>   value: %{\n    ...>     \"contents\" => \"Hello, Bob!\",\n    ...>     \"from\" => %{\n    ...>       \"name\" => \"Cow\",\n    ...>       \"wallet\" => EIP712.Util.decode_hex!(\"0xCD2a3d9F938E13CD947Ec05AbC7FE734Df8DD826\")\n    ...>     },\n    ...>     \"to\" => %{\n    ...>       \"name\" => \"Bob\",\n    ...>       \"wallet\" => EIP712.Util.decode_hex!(\"0xbBbBBBBbbBBBbbbBbbBbbbbBBbBbbbbBbBbbBBbB\")\n    ...>     }\n    ...>   }\n    ...> }\n    ...> |> EIP712.Typed.encode()\n    ...> |> EIP712.Util.encode_hex()\n    \"0x1901f2cee375fa42b42143804025fc449deafd50cc031ca257e0b194a650a912090fc52c0ee5d84264471806290a3f2c4cecfc5490626bf912d01f240d7a274b371e\"\n\n    iex> %EIP712.Typed{\n    ...>   domain: %EIP712.Typed.Domain{\n    ...>     chain_id: 1,\n    ...>     name: \"Test\",\n    ...>     verifying_contract: EIP712.Util.decode_hex!(\"0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC\"),\n    ...>     version: \"1\"\n    ...>   },\n    ...>   types: %{\n    ...>     \"Test\" => %EIP712.Typed.Type{fields: [{\"items\", {:array, :string}}]}\n    ...>   },\n    ...>   value: %{\n    ...>     \"items\" => [\"item1\", \"item2\"]\n    ...>   }\n    ...> }\n    ...> |> EIP712.Typed.encode()\n    ...> |> EIP712.Hash.keccak()\n    ...> |> EIP712.Util.encode_hex()\n    \"0xb5a8bfaa80915247e3a8709778e0e57da2dd5c1c04e07fc4b086d7e4bc9c1715\"","ref":"EIP712.Typed.html#encode/1-examples"},{"type":"function","title":"EIP712.Typed.encode_type/2","doc":"Encodes the struct type per EIP-712. For this, we basically build an ABI-style value\nlike `Mail(Person from,Person to,string contents)`, but then to that we need to append\nany other types we've seen, like:\n\n`Mail(Person from,Person to,string contents)Person(string name,address wallet)`.\n\nThis is a tail-call optimized implementation to build the types then track and append types that need to be added.","ref":"EIP712.Typed.html#encode_type/2"},{"type":"function","title":"Examples - EIP712.Typed.encode_type/2","doc":"iex> EIP712.Typed.encode_type(\"Mail\", %{\n    ...>   \"Mail\" => %EIP712.Typed.Type{fields: [{\"from\", \"Person\"}, {\"to\", \"Person\"}, {\"contents\", :string}]},\n    ...>   \"Person\" => %EIP712.Typed.Type{fields: [{\"name\", :string}, {\"wallet\", :address}]}\n    ...> })\n    \"Mail(Person from,Person to,string contents)Person(string name,address wallet)\"","ref":"EIP712.Typed.html#encode_type/2-examples"},{"type":"function","title":"EIP712.Typed.hash_struct/3","doc":"Hashes a struct value, per the EIP-712 spec.","ref":"EIP712.Typed.html#hash_struct/3"},{"type":"function","title":"Examples - EIP712.Typed.hash_struct/3","doc":"iex> types = %{\n    ...>   \"Mail\" => %EIP712.Typed.Type{fields: [{\"from\", \"Person\"}, {\"to\", \"Person\"}, {\"contents\", :string}]},\n    ...>   \"Person\" => %EIP712.Typed.Type{fields: [{\"name\", :string}, {\"wallet\", :address}]}\n    ...> }\n    ...> value = %{\n    ...>   \"contents\" => \"Hello, Bob!\",\n    ...>   \"from\" => %{\n    ...>     \"name\" => \"Cow\",\n    ...>     \"wallet\" => EIP712.Util.decode_hex!(\"0xCD2a3d9F938E13CD947Ec05AbC7FE734Df8DD826\")\n    ...>   },\n    ...>   \"to\" => %{\n    ...>     \"name\" => \"Bob\",\n    ...>     \"wallet\" => EIP712.Util.decode_hex!(\"0xbBbBBBBbbBBBbbbBbbBbbbbBBbBbbbbBbBbbBBbB\")\n    ...>   }\n    ...> }\n    ...> EIP712.Typed.hash_struct(\"Mail\", value, types)\n    ...> |> EIP712.Util.encode_hex()\n    \"0xc52c0ee5d84264471806290a3f2c4cecfc5490626bf912d01f240d7a274b371e\"","ref":"EIP712.Typed.html#hash_struct/3-examples"},{"type":"function","title":"EIP712.Typed.serialize/1","doc":"Serializes a Typed value, such that it can be passed to JSON or JavaScript.","ref":"EIP712.Typed.html#serialize/1"},{"type":"function","title":"Examples - EIP712.Typed.serialize/1","doc":"iex> %EIP712.Typed{\n    ...>   domain: %EIP712.Typed.Domain{\n    ...>     chain_id: 1,\n    ...>     name: \"Ether Mail\",\n    ...>     verifying_contract: \"\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\\xCC\",\n    ...>     version: \"1\"\n    ...>   },\n    ...>   types: %{\n    ...>     \"Mail\" => %EIP712.Typed.Type{fields: [{\"from\", \"Person\"}, {\"to\", \"Person\"}, {\"contents\", :string}]},\n    ...>     \"Person\" => %EIP712.Typed.Type{fields: [{\"name\", :string}, {\"wallet\", :address}]}\n    ...>   },\n    ...>   value: %{\n    ...>     \"contents\" => \"Hello, Bob!\",\n    ...>     \"from\" => %{\n    ...>       \"name\" => \"Cow\",\n    ...>       \"wallet\" =>  >\n    ...>     },\n    ...>     \"to\" => %{\n    ...>       \"name\" => \"Bob\",\n    ...>       \"wallet\" =>\n    ...>          >\n    ...>     }\n    ...>   }\n    ...> }\n    ...> |> EIP712.Typed.serialize()\n    %{\n      \"domain\" => %{\n        \"name\" => \"Ether Mail\",\n        \"version\" => \"1\",\n        \"chainId\" => 1,\n        \"verifyingContract\" => \"0xcccccccccccccccccccccccccccccccccccccccc\"\n      },\n      \"types\" => %{\n        \"Person\" => [\n          %{\n            \"name\" => \"name\",\n            \"type\" => \"string\"\n          },\n          %{\n            \"name\" => \"wallet\",\n            \"type\" => \"address\"\n          },\n        ],\n        \"Mail\" => [\n          %{\n            \"name\" => \"from\",\n            \"type\" => \"Person\"\n          },\n          %{\n            \"name\" => \"to\",\n            \"type\" => \"Person\"\n          },\n          %{\n            \"name\" => \"contents\",\n            \"type\" => \"string\"\n          },\n        ]\n      },\n      \"value\" => %{\n        \"from\" => %{ \"name\" => \"Cow\", \"wallet\" => \"0xcd2a3d9f938e13cd947ec05abc7fe734df8dd826\" },\n        \"to\" => %{ \"name\" => \"Bob\", \"wallet\" => \"0xbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb\" },\n        \"contents\" => \"Hello, Bob!\"\n      }\n    }","ref":"EIP712.Typed.html#serialize/1-examples"},{"type":"type","title":"EIP712.Typed.t/0","doc":"","ref":"EIP712.Typed.html#t:t/0"},{"type":"type","title":"EIP712.Typed.type_map/0","doc":"","ref":"EIP712.Typed.html#t:type_map/0"},{"type":"type","title":"EIP712.Typed.value_map/0","doc":"","ref":"EIP712.Typed.html#t:value_map/0"},{"type":"module","title":"EIP712.Typed.Domain","doc":"","ref":"EIP712.Typed.Domain.html"},{"type":"function","title":"EIP712.Typed.Domain.deserialize/1","doc":"Deserializes a domain from JSON or JavaScript encoding to a struct.","ref":"EIP712.Typed.Domain.html#deserialize/1"},{"type":"function","title":"Examples - EIP712.Typed.Domain.deserialize/1","doc":"iex> %{\n    ...>   \"name\" => \"Ether Mail\",\n    ...>   \"version\" => \"1\",\n    ...>   \"chainId\" => 1,\n    ...>   \"verifyingContract\" => \"0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC\",\n    ...> }\n    ...> |> EIP712.Typed.Domain.deserialize()\n    %EIP712.Typed.Domain{\n      name: \"Ether Mail\",\n      version: \"1\",\n      chain_id: 1,\n      verifying_contract:  >\n    }","ref":"EIP712.Typed.Domain.html#deserialize/1-examples"},{"type":"function","title":"EIP712.Typed.Domain.domain_type/0","doc":"","ref":"EIP712.Typed.Domain.html#domain_type/0"},{"type":"function","title":"EIP712.Typed.Domain.serialize/1","doc":"Serializes a domain, such that it can be JSON-encoded or passed to JavaScript.","ref":"EIP712.Typed.Domain.html#serialize/1"},{"type":"function","title":"Examples - EIP712.Typed.Domain.serialize/1","doc":"iex> %EIP712.Typed.Domain{\n    ...>   name: \"Ether Mail\",\n    ...>   version: \"1\",\n    ...>   chain_id: 1,\n    ...>   verifying_contract:  >\n    ...> }\n    ...> |> EIP712.Typed.Domain.serialize()\n    %{\n      \"name\" => \"Ether Mail\",\n      \"version\" => \"1\",\n      \"chainId\" => 1,\n      \"verifyingContract\" => \"0xcccccccccccccccccccccccccccccccccccccccc\",\n    }","ref":"EIP712.Typed.Domain.html#serialize/1-examples"},{"type":"function","title":"EIP712.Typed.Domain.serialize_keys/1","doc":"Serializes a domain's keys to be JSON-compatible. This is so that it can be used\nas a value for `hashStruct`, per the EIP-712 spec to build a domain specifier.","ref":"EIP712.Typed.Domain.html#serialize_keys/1"},{"type":"function","title":"Examples - EIP712.Typed.Domain.serialize_keys/1","doc":"iex> %EIP712.Typed.Domain{\n    ...>   name: \"Ether Mail\",\n    ...>   version: \"1\",\n    ...>   chain_id: 1,\n    ...>   verifying_contract:  >\n    ...> }\n    ...> |> EIP712.Typed.Domain.serialize_keys()\n    %{\n      \"name\" => \"Ether Mail\",\n      \"version\" => \"1\",\n      \"chainId\" => 1,\n      \"verifyingContract\" =>  >\n    }","ref":"EIP712.Typed.Domain.html#serialize_keys/1-examples"},{"type":"type","title":"EIP712.Typed.Domain.t/0","doc":"","ref":"EIP712.Typed.Domain.html#t:t/0"},{"type":"module","title":"EIP712.Typed.Type","doc":"","ref":"EIP712.Typed.Type.html"},{"type":"function","title":"EIP712.Typed.Type.deserialize/1","doc":"Deserializes a Type from JSON or a map into a struct.","ref":"EIP712.Typed.Type.html#deserialize/1"},{"type":"function","title":"Examples - EIP712.Typed.Type.deserialize/1","doc":"iex> [%{\n    ...>   \"name\" => \"from\",\n    ...>   \"type\" => \"Person\",\n    ...> }, %{\n    ...>   \"name\" => \"to\",\n    ...>   \"type\" => \"Person\",\n    ...> }, %{\n    ...>   \"name\" => \"contents\",\n    ...>   \"type\" => \"string\",\n    ...> }]\n    ...> |> EIP712.Typed.Type.deserialize()\n    %EIP712.Typed.Type{fields: [{\"from\", \"Person\"}, {\"to\", \"Person\"}, {\"contents\", :string}]}\n\n    iex> [%{\n    ...>   \"name\" => \"items\",\n    ...>   \"type\" => \"string[]\",\n    ...> }]\n    ...> |> EIP712.Typed.Type.deserialize()\n    %EIP712.Typed.Type{fields: [{\"items\", {:array, :string}}]}","ref":"EIP712.Typed.Type.html#deserialize/1-examples"},{"type":"function","title":"EIP712.Typed.Type.deserialize_type/1","doc":"Deserializes a primitive or custom type. We differentiate\ncustom types by not being a primitive type.","ref":"EIP712.Typed.Type.html#deserialize_type/1"},{"type":"function","title":"Examples - EIP712.Typed.Type.deserialize_type/1","doc":"iex> EIP712.Typed.Type.deserialize_type(\"address\")\n    :address\n\n    iex> EIP712.Typed.Type.deserialize_type(\"uint256\")\n    {:uint, 256}\n\n    iex> EIP712.Typed.Type.deserialize_type(\"bytes32\")\n    {:bytes, 32}\n\n    iex> EIP712.Typed.Type.deserialize_type(\"string[]\")\n    {:array, :string}\n\n    iex> EIP712.Typed.Type.deserialize_type(\"Person\")\n    \"Person\"","ref":"EIP712.Typed.Type.html#deserialize_type/1-examples"},{"type":"function","title":"EIP712.Typed.Type.deserialize_value!/2","doc":"Deserializes a value of a given type for being stored in this struct.","ref":"EIP712.Typed.Type.html#deserialize_value!/2"},{"type":"function","title":"Examples - EIP712.Typed.Type.deserialize_value!/2","doc":"iex> EIP712.Typed.Type.deserialize_value!(\"0x0000000000000000000000000000000000000001\", :address)\n     >\n\n    iex> EIP712.Typed.Type.deserialize_value!(55, {:uint, 256})\n    55\n\n    iex> EIP712.Typed.Type.deserialize_value!(\"0x00000000000000000000000000000000000000000000000000000000000000CC\", {:bytes, 32})\n     >\n\n    iex> EIP712.Typed.Type.deserialize_value!(\"0xCC\", {:bytes, 32})\n     >\n\n    iex> EIP712.Typed.Type.deserialize_value!(\"Cow\", :string)\n    \"Cow\"","ref":"EIP712.Typed.Type.html#deserialize_value!/2-examples"},{"type":"function","title":"EIP712.Typed.Type.encode_data_value/2","doc":"Encodes a value for `encodeData`, as per the EIP-712 spec. Specifically, raw values are\nexpanded to 32-bytes, and dynamic types are hashed.","ref":"EIP712.Typed.Type.html#encode_data_value/2"},{"type":"function","title":"Examples - EIP712.Typed.Type.encode_data_value/2","doc":"iex> EIP712.Typed.Type.encode_data_value( >, :address)\n     >\n\n    iex> EIP712.Typed.Type.encode_data_value(55, {:uint, 256})\n     >\n\n    iex> EIP712.Typed.Type.encode_data_value( >, {:bytes, 32})\n     >\n\n    iex> EIP712.Typed.Type.encode_data_value(\"foo\", :string) |> EIP712.Util.encode_hex()\n    \"0x41b1a0649752af1b28b3dc29a1556eee781e4a4c3a1f7f53f90fa834de098c4d\"\n\n    iex> EIP712.Typed.Type.encode_data_value([\"foo\", \"bar\"], {:array, :string}) |> EIP712.Util.encode_hex()\n    \"0x744766909640c85c19ca00139e7af3c5d9cb8dbfbc6635812eedc4e3cbf4fce6\"","ref":"EIP712.Typed.Type.html#encode_data_value/2-examples"},{"type":"function","title":"EIP712.Typed.Type.serialize/1","doc":"Serializes a Type, such that it can be used with JSON or JavaScript.","ref":"EIP712.Typed.Type.html#serialize/1"},{"type":"function","title":"Examples - EIP712.Typed.Type.serialize/1","doc":"iex> %EIP712.Typed.Type{fields: [{\"from\", \"Person\"}, {\"to\", \"Person\"}, {\"contents\", :string}]}\n    ...> |> EIP712.Typed.Type.serialize()\n    [%{\n      \"name\" => \"from\",\n      \"type\" => \"Person\",\n    }, %{\n      \"name\" => \"to\",\n      \"type\" => \"Person\",\n    }, %{\n      \"name\" => \"contents\",\n      \"type\" => \"string\",\n    }]\n\n\n    iex> %EIP712.Typed.Type{fields: [{\"items\", {:array, :string}}]}\n    ...> |> EIP712.Typed.Type.serialize()\n    [%{\n      \"name\" => \"items\",\n      \"type\" => \"string[]\",\n    }]","ref":"EIP712.Typed.Type.html#serialize/1-examples"},{"type":"function","title":"EIP712.Typed.Type.serialize_type/1","doc":"Serializes a primitive or custom type.","ref":"EIP712.Typed.Type.html#serialize_type/1"},{"type":"function","title":"Examples - EIP712.Typed.Type.serialize_type/1","doc":"iex> EIP712.Typed.Type.serialize_type(:address)\n    \"address\"\n\n    iex> EIP712.Typed.Type.serialize_type({:uint, 256})\n    \"uint256\"\n\n    iex> EIP712.Typed.Type.serialize_type({:bytes, 32})\n    \"bytes32\"\n\n    iex> EIP712.Typed.Type.serialize_type({:array, :string})\n    \"string[]\"\n\n    iex> EIP712.Typed.Type.serialize_type(\"Person\")\n    \"Person\"","ref":"EIP712.Typed.Type.html#serialize_type/1-examples"},{"type":"function","title":"EIP712.Typed.Type.serialize_value/2","doc":"Serializes a value of a given type to pass to JSON or JavaScript.","ref":"EIP712.Typed.Type.html#serialize_value/2"},{"type":"function","title":"Examples - EIP712.Typed.Type.serialize_value/2","doc":"iex> EIP712.Typed.Type.serialize_value( >, :address)\n    \"0x0000000000000000000000000000000000000001\"\n\n    iex> EIP712.Typed.Type.serialize_value(55, {:uint, 256})\n    55\n\n    iex> EIP712.Typed.Type.serialize_value( >, {:bytes, 32})\n    \"0x00000000000000000000000000000000000000000000000000000000000000cc\"\n\n    iex> EIP712.Typed.Type.serialize_value( >, {:bytes, 32})\n    \"0x00000000000000000000000000000000000000000000000000000000000000cc\"\n\n    iex> EIP712.Typed.Type.serialize_value(\"Cow\", :string)\n    \"Cow\"\n\n    iex> EIP712.Typed.Type.serialize_value([\"foo\", \"bar\"], {:array, :string})\n    [\"foo\", \"bar\"]","ref":"EIP712.Typed.Type.html#serialize_value/2-examples"},{"type":"type","title":"EIP712.Typed.Type.field/0","doc":"","ref":"EIP712.Typed.Type.html#t:field/0"},{"type":"type","title":"EIP712.Typed.Type.field_type/0","doc":"","ref":"EIP712.Typed.Type.html#t:field_type/0"},{"type":"type","title":"EIP712.Typed.Type.primitive/0","doc":"","ref":"EIP712.Typed.Type.html#t:primitive/0"},{"type":"type","title":"EIP712.Typed.Type.t/0","doc":"","ref":"EIP712.Typed.Type.html#t:t/0"},{"type":"type","title":"EIP712.Typed.Type.type_list/0","doc":"","ref":"EIP712.Typed.Type.html#t:type_list/0"},{"type":"module","title":"EIP712.Util","doc":"","ref":"EIP712.Util.html"},{"type":"function","title":"EIP712.Util.checksum_address/1","doc":"Checksums an Ethereum address per [EIP-55](https://github.com/ethereum/EIPs/blob/master/EIPS/eip-55.md),\nthe result is a string-encoded version of the address.","ref":"EIP712.Util.html#checksum_address/1"},{"type":"function","title":"Examples - EIP712.Util.checksum_address/1","doc":"iex> EIP712.Util.checksum_address(\"0x5aaeb6053f3e94c9b9a09f33669435e7ef1beaed\")\n    \"0x5aAeb6053F3E94C9b9A09f33669435E7Ef1BeAed\"\n\n    iex> EIP712.Util.checksum_address(\"0xFB6916095CA1DF60BB79CE92CE3EA74C37C5D359\")\n    \"0xfB6916095ca1df60bB79Ce92cE3Ea74c37c5d359\"\n\n    iex> EIP712.Util.checksum_address(\"0xdbf03b407c01e7cd3cbea99509d93f8dddc8c6fb\")\n    \"0xdbF03B407c01E7cD3CBea99509d93f8DDDC8C6FB\"\n\n    iex> EIP712.Util.checksum_address(\"0xd1220a0cf47c7b9be7a2e6ba89f429762e7b9adb\")\n    \"0xD1220A0cf47c7B9Be7A2E6BA89F429762e7b9aDb\"","ref":"EIP712.Util.html#checksum_address/1-examples"},{"type":"function","title":"EIP712.Util.decode_hex/1","doc":"Decodes a hex string, specifically requiring that the string begins\nwith `0x` and allows mixed-case typing.","ref":"EIP712.Util.html#decode_hex/1"},{"type":"function","title":"Examples - EIP712.Util.decode_hex/1","doc":"iex> EIP712.Util.decode_hex(\"0x1122\")\n  {:ok,  >}\n\n  iex> EIP712.Util.decode_hex(\"0x1\")\n  {:ok,  >}\n\n  iex> EIP712.Util.decode_hex(\"0xGG\")\n  :error","ref":"EIP712.Util.html#decode_hex/1-examples"},{"type":"function","title":"EIP712.Util.decode_hex!/1","doc":"","ref":"EIP712.Util.html#decode_hex!/1"},{"type":"function","title":"EIP712.Util.decode_hex_input!/1","doc":"Decodes hex, allowing it to either by \"0x...\" or  >.\n\nNote: a hex-printed string, in this case, must start with 0x,\n      otherwise it will be interpreted as its ASCII values.","ref":"EIP712.Util.html#decode_hex_input!/1"},{"type":"function","title":"Examples - EIP712.Util.decode_hex_input!/1","doc":"iex> EIP712.Util.decode_hex_input!(\"0x55\")\n     >\n\n    iex> EIP712.Util.decode_hex_input!( >)\n     >","ref":"EIP712.Util.html#decode_hex_input!/1-examples"},{"type":"function","title":"EIP712.Util.encode_bytes/2","doc":"Encodes a number as a binary representation of a certain number of\nbytes.","ref":"EIP712.Util.html#encode_bytes/2"},{"type":"function","title":"Examples - EIP712.Util.encode_bytes/2","doc":"iex> EIP712.Util.encode_bytes(257, 4)\n   >\n\n  iex> EIP712.Util.encode_bytes(nil, 4)\n  nil","ref":"EIP712.Util.html#encode_bytes/2-examples"},{"type":"function","title":"EIP712.Util.encode_hex/2","doc":"Encodes a hex string, adding a `0x` prefix.\n\nNote: if `short` is set, then any leading zeros will be stripped.","ref":"EIP712.Util.html#encode_hex/2"},{"type":"function","title":"Examples - EIP712.Util.encode_hex/2","doc":"iex> EIP712.Util.encode_hex( >)\n  \"0x1122\"\n\n  iex> EIP712.Util.encode_hex( >)\n  \"0x0c\"\n\n  iex> EIP712.Util.encode_hex( >, true)\n  \"0xc\"\n\n  iex> EIP712.Util.encode_hex( >, true)\n  \"0x0\"","ref":"EIP712.Util.html#encode_hex/2-examples"},{"type":"function","title":"EIP712.Util.get_eth_address/1","doc":"Returns an Ethereum address from a given DER-encoded public key.","ref":"EIP712.Util.html#get_eth_address/1"},{"type":"function","title":"Examples - EIP712.Util.get_eth_address/1","doc":"iex> public_key = EIP712.Util.decode_hex!(\"0x0422\")\n  iex> EIP712.Util.get_eth_address(public_key) |> EIP712.Util.encode_hex()\n  \"0x759f1afdc24aba433a3e18b683f8c04a6eaa69f0\"","ref":"EIP712.Util.html#get_eth_address/1-examples"},{"type":"function","title":"EIP712.Util.keccak/1","doc":"","ref":"EIP712.Util.html#keccak/1"},{"type":"function","title":"EIP712.Util.nibbles/1","doc":"Returns the nibbles of a binary as a list.","ref":"EIP712.Util.html#nibbles/1"},{"type":"function","title":"Examples - EIP712.Util.nibbles/1","doc":"iex> EIP712.Util.nibbles( >)\n    [0xF, 0x5, 0xE, 0x6, 0xD, 0x0]","ref":"EIP712.Util.html#nibbles/1-examples"},{"type":"function","title":"EIP712.Util.pad/2","doc":"Pads a binary to a given length","ref":"EIP712.Util.html#pad/2"},{"type":"function","title":"Examples - EIP712.Util.pad/2","doc":"iex> EIP712.Util.pad( >, 2)\n   >\n\n  iex> EIP712.Util.pad( >, 4)\n   >\n\n  iex> EIP712.Util.pad( >, 1)\n  ** (FunctionClauseError) no function clause matching in EIP712.Util.pad/2","ref":"EIP712.Util.html#pad/2-examples"},{"type":"function","title":"EIP712.Util.parse_chain_id/1","doc":"Parses a chain id, which can be given as an integer or an atom of a known network.","ref":"EIP712.Util.html#parse_chain_id/1"},{"type":"function","title":"Examples - EIP712.Util.parse_chain_id/1","doc":"iex> EIP712.Util.parse_chain_id(5)\n    5\n\n    iex> EIP712.Util.parse_chain_id(:goerli)\n    5","ref":"EIP712.Util.html#parse_chain_id/1-examples"},{"type":"function","title":"EIP712.Util.to_wei/1","doc":"Converts a number to wei, possibly from gwei, etc.","ref":"EIP712.Util.html#to_wei/1"},{"type":"function","title":"Examples - EIP712.Util.to_wei/1","doc":"iex> EIP712.Util.to_wei(100)\n    100\n\n    iex> EIP712.Util.to_wei({100, :gwei})\n    100000000000","ref":"EIP712.Util.html#to_wei/1-examples"},{"type":"module","title":"EIP712.Util.RecoveryBit","doc":"There are a number of ways to look at recovery bits. Either:\n\n* `:base`: In the range `{0,1}`, which are the outputs of a signer library\n* `:ethereum`: In the range `{27,28}`, as defined in the yellow paper\n* `:eip155`: In the range `{35+chain_id*2,35+chain_id*2+1}`, as defined in EIP-155\n\nThis module provides tools between switching through these choices.","ref":"EIP712.Util.RecoveryBit.html"}],"content_type":"text/markdown"}